@@ -9,10 +9,9 @@ using namespace Wt;
 #endif // WT_TARGET_JAVA
 
 SAMPLE_BEGIN(TextEdit)
-auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
+auto container = std::make_unique<Wt::WContainerWidget>();
 
-Wt::WTextEdit *edit =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WTextEdit>());
+Wt::WTextEdit *edit = container->addNew<Wt::WTextEdit>();
 edit->setHeight(300);
 edit->setText("<p>"
     "<span style=\"font-family: 'courier new', courier; font-size: medium;\">"
@@ -20,7 +19,7 @@ edit->setText("<p>"
     "<p>Hey, I'm a <strong>WTextEdit</strong> and you can make me"
         " <span style=\"text-decoration: underline;\"><em>rich</em></span>"
         " by adding your <span style=\"color: #ff0000;\"><em>style</em>"
-	"</span>!</p>"
+        "</span>!</p>"
     "<p>Other widgets like...</p>"
       "<ul style=\"padding: 0px; margin: 0px 0px 10px 25px;\">"
         "<li>WLineEdit</li>"
@@ -29,12 +28,10 @@ edit->setText("<p>"
       "</ul>"
     "<p>don't have style.</p>");
 
-Wt::WPushButton *button =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WPushButton>("Get text"));
+Wt::WPushButton *button = container->addNew<Wt::WPushButton>("Get text");
 button->setMargin(10, Wt::Side::Top | Wt::Side::Bottom);
 
-Wt::WText *out =
-    container->addWidget(Wt::cpp14::make_unique<Wt::WText>());
+Wt::WText *out = container->addNew<Wt::WText>();
 out->setStyleClass("xhtml-output");
 
 button->clicked().connect([=] {
